==> haskell-aeson-yaml-1.1.0.1-319-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-qbTnQYg4UDFsg9b7of1Rh
key:                  aeson-yaml-1.1.0.1-qbTnQYg4UDFsg9b7of1Rh
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  7d75a79260f3a410cbb176bb1ec4b60c
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-qbTnQYg4UDFsg9b7of1Rh
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-yaml-1.1.0.1-338-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-4YQukpVafuk6BplBgyV098
key:                  aeson-yaml-1.1.0.1-4YQukpVafuk6BplBgyV098
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  b36fa3c3f504314a74507c61bd3d0f00
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-4YQukpVafuk6BplBgyV098
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
